<?php
/**
*
* @package phpBB3
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : '../';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);
include($phpbb_root_path . 'includes/functions_posting.' . $phpEx);
include($phpbb_root_path . 'includes/functions_display.' . $phpEx);
include($phpbb_root_path . 'includes/message_parser.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup(array('posting', 'mcp', 'viewtopic'));

$article_id = request_var('a', 0);

$submit = (isset($_POST['post'])) ? true : false;
$preview = (isset($_POST['preview'])) ? true : false;
$cancel = (isset($_POST['cancel'])) ? true : false;

$mode = request_var('mode', '');

$error = $article_data = array();
$current_time = time();

if ($cancel)
{
	$redirect = ($article_id) ? append_sid("{$phpbb_root_path}kb/viewarticle.$phpEx", 'a=' . $article_id) : append_sid("{$phpbb_root_path}kb/index.$phpEx");
	redirect($redirect);
}

if (!in_array($mode, array('post', 'edit', 'delete')))
{
	trigger_error('NO_POST_MODE');
}

switch ($mode)
{
	case 'edit':
	case 'delete':
		if (!$article_id)
		{
			trigger_error('NO_ARTICLE');
		}

		$sql = 'SELECT a.*, c.*
			FROM ' . KB_ARTICLES_TABLE . ' a, ' . KB_CATEGORIES_TABLE . ' c
			WHERE a.article_id = ' . (int) $article_id . '
				AND a.category_id = c.category_id';
	break;

	default:
		$sql = '';
	break;
}

if (!$sql && $mode != 'post')
{
	trigger_error('NO_POST_MODE');
}

$result = $db->sql_query($sql);
$article_data = $db->sql_fetchrow($result);
$db->sql_freeresult($result);

if (!$article_data && $mode != 'post')
{
	trigger_error('NO_ARTICLE');
}

switch ($mode)
{
	case 'post':
		if (!$auth->acl_get('u_kb_post'))
		{
			trigger_error('NOT_AUTHORISED');
		}
	break;

	case 'edit':
		if ((!$auth->acl_get('u_kb_edit') || $user->data['user_id'] != $article_data['poster_id']) && !$auth->acl_get('m_kb_edit'))
		{
			trigger_error('NOT_AUTHORISED');
		}
	break;

	case 'delete':
		if ((!$auth->acl_get('u_kb_delete') || $user->data['user_id'] != $article_data['poster_id']) && !$auth->acl_get('m_kb_delete'))
		{
			trigger_error('NOT_AUTHORISED');
		}
	break;
}

if ($mode == 'delete')
{
	if (confirm_box(true))
	{
		$sql = 'DELETE FROM ' . KB_ARTICLES_TABLE . '
			WHERE article_id = ' . (int) $article_id;
		$db->sql_query($sql);

		$meta_info = append_sid("{$phpbb_root_path}kb/index.{$phpEx}");

		meta_refresh(3, $meta_info);

		$message = $user->lang['ARTICLE_DELETED_SUCCESS'];

		trigger_error($message);
	}
	else
	{
		confirm_box(false, $user->lang['DELETE_ARTICLE_CONFIRM']);
	}
}

$message_parser = new parse_message();

if (isset($article_data['message']))
{
	$message_parser->message = &$article_data['message'];
	unset($article_data['message']);
}

$uninit = array('poster_id' => $user->data['user_id'], 'article_title' => '', 'article_description' => '');

foreach ($uninit as $var_name => $default_value)
{
	if (!isset($article_data[$var_name]))
	{
		$article_data[$var_name] = $default_value;
	}
}
unset($uninit);

$article_data['category_id'] = ($mode == 'edit') ? $article_data['category_id'] : 0;
$article_data['enable_bbcode'] = true;
$article_data['enable_smilies'] = true;
$article_data['enable_magic_url'] = true;

if ($mode == 'edit' && $article_data['bbcode_uid'])
{
	$message_parser->bbcode_uid = $article_data['bbcode_uid'];
}

if ($submit || $preview)
{
	$article_data['article_title'] = utf8_normalize_nfc(request_var('article_title', '', true));
	$article_data['article_description'] = utf8_normalize_nfc(request_var('article_description', '', true));
	$article_data['category_id'] = request_var('category_id', 0);
	$message_parser->message = utf8_normalize_nfc(request_var('message', '', true));

	$message_parser->parse($article_data['enable_bbcode'], $article_data['enable_magic_url'], $article_data['enable_smilies']);

	if (utf8_clean_string($article_data['article_title']) === '' && ($mode == 'post' || $mode == 'edit'))
	{
		$error[] = $user->lang['EMPTY_ARTICLE_TITLE'];
	}

	if (utf8_clean_string($article_data['article_description']) === '' && ($mode == 'post' || $mode == 'edit'))
	{
		$error[] = $user->lang['EMPTY_ARTICLE_DESCRIPTION'];
	}

	if (!$article_data['category_id'] && ($mode == 'post' || $mode == 'edit'))
	{
		$error[] = $user->lang['EMPTY_CATEGORY_ID'];
	}

	if ($message_parser->message === '' && ($mode == 'post' || $mode == 'edit'))
	{
		$error[] = $user->lang['EMPTY_MESSAGE'];
	}

	if (!sizeof($error) && $submit)
	{
		$data = array(
			'category_id'			=> (int) $article_data['category_id'],
			'article_approved'		=> (isset($article_data['article_approved'])) ? $article_data['article_approved'] : false,
			'article_denied'		=> (isset($article_data['article_denied'])) ? $article_data['article_denied'] : false,
			'article_title'			=> $article_data['article_title'],
			'article_description'	=> $article_data['article_description'],
			'poster_id'				=> (int) $article_data['poster_id'],
			'article_time'			=> (isset($article_data['article_time'])) ? (int) $article_data['article_time'] : $current_time,
			'enable_bbcode'			=> (bool) $article_data['enable_bbcode'],
			'enable_smilies'		=> (bool) $article_data['enable_smilies'],
			'enable_magic_url'		=> (bool) $article_data['enable_magic_url'],
			'message'				=> $message_parser->message,
			'bbcode_bitfield'		=> $message_parser->bbcode_bitfield,
			'bbcode_uid'			=> $message_parser->bbcode_uid,
		);

		if (!$article_id)
		{
			$sql = 'INSERT INTO ' . KB_ARTICLES_TABLE . ' ' . $db->sql_build_array('INSERT', $data);
		}
		else
		{
			$sql = 'UPDATE ' . KB_ARTICLES_TABLE . ' SET ' . $db->sql_build_array('UPDATE', $data) . 'WHERE article_id = ' . (int) $article_id;
		}
		$db->sql_query($sql);

		if ($auth->acl_get('m_kb_approve') || $data['article_approved'])
		{
			$redirect_url = append_sid("{$phpbb_root_path}kb/viewarticle.{$phpEx}", 'a=' . (($article_id) ? $article_id : $db->sql_nextid()));
			$message = $user->lang['ARTICLE_POSTED'];
		}
		else
		{
			$redirect_url = append_sid("{$phpbb_root_path}kb/index.{$phpEx}");
			$message = $user->lang['ARTICLE_POSTED_MOD'];
		}
		meta_refresh(3, $redirect_url);
		trigger_error($message);
	}
}

if (!sizeof($error) && $preview)
{
	$article_data['article_time'] = ($mode == 'edit') ? $article_data['article_time'] : $current_time;

	$preview_message = $message_parser->format_display($article_data['enable_bbcode'], $article_data['enable_magic_url'], $article_data['enable_smilies'], false);

	$preview_subject = censor_text($article_data['article_title']);
	$preview_description = censor_text($article_data['article_description']);

	if (!sizeof($error))
	{
		$template->assign_vars(array(
			'PREVIEW_SUBJECT'		=> $preview_subject,
			'PREVIEW_DESCRIPTION'	=> $preview_description,
			'PREVIEW_MESSAGE'		=> $preview_message,

			'S_DISPLAY_PREVIEW'		=> true)
		);
	}
}

$article_data['bbcode_uid'] = (!$preview && !sizeof($error) && $mode == 'edit') ? $article_data['bbcode_uid'] : $message_parser->bbcode_uid;
$message_parser->decode_message($article_data['bbcode_uid']);

$article_data['message'] = $message_parser->message;

generate_smilies('inline', 0);

$s_action = append_sid("{$phpbb_root_path}kb/posting.$phpEx", "mode=$mode");
$s_action .= ($article_id) ? "&amp;a=$article_id" : '';

$sql = 'SELECT *
	FROM ' . KB_CATEGORIES_TABLE . '
	ORDER BY left_id ASC';
$result = $db->sql_query($sql);
$category_id_array = array();
while ($row = $db->sql_fetchrow($result))
{
	$category_id_array[] .= $row['category_id'];

	$template->assign_block_vars('categories', array(
		'CATEGORY_ID'	=> $row['category_id'],
		'CATEGORY_NAME'	=> $row['category_name'],
		'SELECTED'		=> ($row['category_id'] == $article_data['category_id']) ? ' selected="selected"' : '',
	));
}
$db->sql_freeresult($result);

$template->assign_vars(array(
	'ARTICLE_TITLE'			=> censor_text($article_data['article_title']),
	'ARTICLE_DESCRIPTION'	=> censor_text($article_data['article_description']),
	'CATEGORY_ID'			=> $article_data['category_id'],
	'MESSAGE'				=> $article_data['message'],

	'ERROR'	=> (sizeof($error)) ? implode('<br />', $error) : '',

	'U_ACTION'			=> $s_action,
	'U_MORE_SMILIES'	=> append_sid("{$phpbb_root_path}posting.$phpEx", 'mode=smilies'),

	'S_BBCODE_ALLOWED'	=> true,
	'S_LINKS_ALLOWED'	=> true,
	'S_BBCODE_IMG'		=> true,
	'S_BBCODE_QUOTE'	=> true,
));

display_custom_bbcodes();

$template->assign_block_vars('navlinks', array(
	'FORUM_NAME' => $user->lang['KNOWLEDGE_BASE'],
	'U_VIEW_FORUM' => append_sid("{$phpbb_root_path}kb/index.$phpEx"),
));

page_header($user->lang['KNOWLEDGE_BASE']);

$template->set_filenames(array(
	'body' => 'kb/posting_body.html')
);

page_footer();

?>